# -*- coding: utf-8 -*-
"""
    celery.security.utils
    ~~~~~~~~~~~~~~~~~~~~~

    Utilities used by the message signing serializer.

"""


import sys

from contextlib import contextmanager

from celery.exceptions import SecurityError

try:
    from OpenSSL import crypto
except ImportError:  # pragma: no cover
    crypto = None    # noqa


@contextmanager
def reraise_errors(msg='%r', errors=None):
    assert crypto is not None
    errors = (crypto.Error, ) if errors is None else errors
    try:
        yield
    except errors as exc:
        raise SecurityError(SecurityError(msg % (exc, ))).with_traceback(sys.exc_info()[2])
